@@ -3,6 +3,6 @@ def print_list(lista,level):
 		if(isinstance(x,list)):
 			print_list(x,level+1)
 		else:
-			for s in rang(level)
+			for s in rang(level):
 				print("\t",end='')
 			print(x)
